@@ -35,10 +35,15 @@ class VialRequestHandler(wsgiref.simple_server.WSGIRequestHandler):
 
 
 class Vial():
-    def __init__(self, app_name="Vial", logger=None):
-        self.headers = {
-                "Server" : app_name
-            }
+    def __init__(self, app_name="Vial", logger=None, **kwargs):
+        # Server settings
+        self.settings = {
+            "simple_response_always_200" : True
+        }
+        self.settings.update(kwargs)
+
+        # Default headers
+        self.headers = {"Server" : app_name}
         self.response = VResponse(self)
         self.app_name = app_name
         self._logger = logger
@@ -72,7 +77,10 @@ class Vial():
                 self.logger.debug(format_traceback())
             status, headers, body = self.response(500)
 
-        respond(status, headers)
+        respond(
+            status,
+            [(key, str(value)) for key, value in headers.items() if value]
+        )
         if request.method == "HEAD":
             yield b""
             return
@@ -107,3 +115,4 @@ class Vial():
             os.kill(os.getpid(), signal.CTRL_BREAK_EVENT)
         else:
             os.kill(os.getpid(), signal.SIGTERM)
+
