@@ -1,5 +1,7 @@
 import json
 import copy
+import inspect
+
 from http import HTTPStatus
 
 
@@ -11,18 +13,13 @@ def response_type(func):
     def wrapper(parent, body=None, status=200, headers={}):
         all_headers = copy.copy(parent.app.headers)
         body, rheaders = func(parent, body, status)
-        all_headers["Content-Length"] = len(body)
+        if not inspect.isgeneratorfunction(body):
+            all_headers["Content-Length"] = len(body)
         for k, v in rheaders.items():
             all_headers[k] = v
         all_headers.update(headers)
 
-        list_headers = []
-        for key, value in all_headers.items():
-            if not value:
-                return
-            list_headers.append((key, str(value)))
-
-        return format_status(status), list_headers, body
+        return format_status(status), all_headers, body
     return wrapper
 
 
@@ -31,13 +28,13 @@ class VResponse():
         self.app = app
 
     def __call__(self, status=200, message=None, headers={}, **kwargs):
+        hstatus = 200 if self.app.settings["simple_response_always_200"] else status
         data = {
             "response" : status,
             "message" : HTTPStatus(status).phrase if message is None else message,
             **kwargs
         }
-        return self.json(data, status=status, headers=headers)
-
+        return self.json(data, status=hstatus, headers=headers)
 
     @response_type
     def text(self, body, status):
@@ -63,3 +60,4 @@ class VResponse():
             return body.encode("utf-8"), headers
         else:
             return str(body).encode("utf-8"), headers
+
